summaryrefslogtreecommitdiffstats
path: root/src/lib/Bcfg2/Server/Plugins/Packages/Collection.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/Bcfg2/Server/Plugins/Packages/Collection.py')
-rw-r--r--src/lib/Bcfg2/Server/Plugins/Packages/Collection.py16
1 files changed, 13 insertions, 3 deletions
diff --git a/src/lib/Bcfg2/Server/Plugins/Packages/Collection.py b/src/lib/Bcfg2/Server/Plugins/Packages/Collection.py
index a0646d101..ec9ba550b 100644
--- a/src/lib/Bcfg2/Server/Plugins/Packages/Collection.py
+++ b/src/lib/Bcfg2/Server/Plugins/Packages/Collection.py
@@ -93,7 +93,8 @@ class Collection(list, Bcfg2.Server.Plugin.Debuggable):
#: Whether or not this Packages backend supports package groups
__package_groups__ = False
- def __init__(self, metadata, sources, basepath, debug=False):
+ def __init__(self, metadata, sources, cachepath, basepath, fam,
+ debug=False):
"""
:param metadata: The client metadata for this collection
:type metadata: Bcfg2.Server.Plugins.Metadata.ClientMetadata
@@ -103,9 +104,16 @@ class Collection(list, Bcfg2.Server.Plugin.Debuggable):
:type sources: list of
:class:`Bcfg2.Server.Plugins.Packages.Source.Source`
objects
- :param basepath: The base filesystem path where cache and
- other temporary data will be stored
+ :param cachepath: The filesystem path where cache and other temporary
+ data will be stored
+ :type cachepath: string
+ :param basepath: The filesystem path to the Packages plugin
+ directory, where more permanent data can be
+ stored
:type basepath: string
+ :param fam: A file monitor object to use if this Collection
+ needs to monitor for file activity
+ :type fam: Bcfg2.Server.FileMonitor.FileMonitor
:param debug: Enable debugging output
:type debug: bool
@@ -116,7 +124,9 @@ class Collection(list, Bcfg2.Server.Plugin.Debuggable):
self.debug_flag = debug
self.metadata = metadata
self.basepath = basepath
+ self.cachepath = cachepath
self.virt_pkgs = dict()
+ self.fam = fam
try:
self.setup = sources[0].setup